pub struct DhcpClientTask { /* private fields */ }Expand description
Task for polling the DHCP client.
Implementations
Sourceimpl DhcpClientTask
impl DhcpClientTask
Sourcepub fn new(
client: ClientProxy,
id: NonZeroU64,
route_set: RouteSetV4Proxy,
control: Control,
) -> DhcpClientTask
pub fn new( client: ClientProxy, id: NonZeroU64, route_set: RouteSetV4Proxy, control: Control, ) -> DhcpClientTask
Creates and returns an async task that polls the DHCP client.
Sourcepub fn wait_shutdown(&self) -> impl Future<Output = ()> + 'static
pub fn wait_shutdown(&self) -> impl Future<Output = ()> + 'static
Returns a future that resolves when the running DHCP client has shut down.